SunmiPrinterX class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addText(String printerId, String text, {int textWidthRatio = 0, int textHeightRatio = 0, int textSpace = 0, bool bold = false, bool underline = false, bool strikethrough = false, bool italic = false, Align align = Align.left})
→ Future<void>
-
-
autoOut(String printerId)
→ Future<void>
-
-
getPrinters()
→ Future<List<Printer>>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
printQrCode(String printerId, String data, {int dot = 3, Align align = Align.center})
→ Future<void>
-
-
printText(String printerId, String text, {int textWidthRatio = 0, int textHeightRatio = 0, int textSpace = 0, bool bold = false, bool underline = false, bool strikethrough = false, bool italic = false, Align align = Align.left})
→ Future<void>
-
-
printTexts(String printerId, List<String> texts, {List<int> columnWidths = const [], List<Align> columnAligns = const []})
→ Future<void>
-
-
setAlarmLampColorBlinking(AlarmLampColor color, int onTime, int offTime)
→ Future<void>
-
-
setAlarmLampColorStatic(AlarmLampColor color)
→ Future<void>
-
-
setAlarmLampsOff()
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited